@@ -7,7 +7,7 @@ from .constants import (
     BALLOON_PAYMENT_FINAL_INPUT_XML,
     BALLOON_PAYMENT_REGULAR_INPUT_XML,
     EQUAL_PAYMENT_INPUT_XML,
-    AccuralCode,
+    AccrualCode,
     PaymentsPerYear,
 )
 from .utils import ValidationError, validate_inputs
@@ -29,7 +29,7 @@ class ScexClient:
 
         options.setdefault("Account", 1)
         options.setdefault("DataDirPath", "/etc/sce/*")
-        options.setdefault("AccuralCode", AccuralCode.ACTUAL_360_SIMPLE.value)
+        options.setdefault("AccrualCode", AccrualCode.ACTUAL_360_US_RULE.value)
         options.setdefault("AprType", "default")
         options.setdefault("UseMAPR", "false")
         options.setdefault("HideAmort", "false")
