@@ -2,7 +2,7 @@
 
 from datetime import datetime
 
-from .constants import AccuralCode
+from .constants import AccrualCode
 
 
 class ValidationError(Exception):
@@ -33,6 +33,6 @@ def validate_inputs(options: dict):
         raise ValidationError("IntRate is required")
 
     try:
-        AccuralCode(options["AccuralCode"])
+        AccrualCode(options["AccrualCode"])
     except ValueError:
         raise ValidationError("Accural code not supported")
